@@ -1,7 +1,7 @@
 #/bin/env python
 #coding:UTF-8
 '''一个用来递归打印列表中所有元素的函数。'''
-def print_lol(the_list, indent=false, level=0):
+def print_lol(the_list, indent=False, level=0):
 	for each_item in the_list:
 		if isinstance(each_item, list):
 			print_lol(each_item, indent, level+1)
